@@ -176,6 +176,11 @@ def registerAllExtras():
 # Functions from module python
 #
 
+def loaderFunc():
+    """Get the function for controlling document loading"""
+    ret = libxsltmod.xsltGetLoaderFunc()
+    return ret
+
 def pythonCleanup():
     """Cleanup just libxslt (not libxml2) memory allocated"""
     libxsltmod.xsltPythonCleanup()
@@ -306,19 +311,11 @@ def nsProp(node, name, nameSpace):
     ret = libxsltmod.xsltGetNsProp(node__o, name, nameSpace)
     return ret
 
-def setDebuggerStatus(value):
-    """This function sets the value of xslDebugStatus."""
-    libxsltmod.xsltSetDebuggerStatus(value)
-
 def timestamp():
     """Used for gathering profiling data"""
     ret = libxsltmod.xsltTimestamp()
     return ret
 
-def xslDropCall():
-    """Drop the topmost item off the call stack"""
-    libxsltmod.xslDropCall()
-
 class xpathParserContext(libxml2.xpathParserContext):
     def __init__(self, _obj=None):
         self._o = None
